// +-------------------------------- DISCLAIMER ---------------------------------+
// |                                                                             |
// | This application program is provided to you free of charge as an example.   |
// | Despite the considerable efforts of Euresys personnel to create a usable    |
// | example, you should not assume that this program is error-free or suitable  |
// | for any purpose whatsoever.                                                 |
// |                                                                             |
// | EURESYS does not give any representation, warranty or undertaking that this |
// | program is free of any defect or error or suitable for any purpose. EURESYS |
// | shall not be liable, in contract, in torts or otherwise, for any damages,   |
// | loss, costs, expenses or other claims for compensation, including those     |
// | asserted by third parties, arising out of or in connection with the use of  |
// | this program.                                                               |
// |                                                                             |
// +-----------------------------------------------------------------------------+

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

// Open eVision Namespace
using Euresys.Open_eVision_1_2;

namespace OeVProjectSample
{
	/// <summary>
	/// Summary description for Form1.
	/// </summary>
	public class MainForm : System.Windows.Forms.Form
	{
		private System.Windows.Forms.OpenFileDialog openFileDialog;
		private System.Windows.Forms.MainMenu mainMenu;
		private System.Windows.Forms.MenuItem File;
		private System.Windows.Forms.MenuItem FileOpen;
		private System.Windows.Forms.MenuItem FileExit;
		private System.Windows.Forms.MenuItem menuItem1;
		private System.Windows.Forms.MenuItem menuItem2;
		private System.Windows.Forms.MenuItem ApplicationIntroduction;

		// Open eVision objects
		private EImageBW8 _image= new EImageBW8();
		private EROIBW8 _roi= new EROIBW8();
		private EDragHandle _handle= EDragHandle.NoHandle;

		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public MainForm()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			//
			// TODO: Add any constructor code after InitializeComponent call
			//
			// Welcome message box
			ApplicationIntroduction_Click(null, null);
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.openFileDialog = new System.Windows.Forms.OpenFileDialog();
			this.mainMenu = new System.Windows.Forms.MainMenu();
			this.File = new System.Windows.Forms.MenuItem();
			this.FileOpen = new System.Windows.Forms.MenuItem();
			this.menuItem1 = new System.Windows.Forms.MenuItem();
			this.FileExit = new System.Windows.Forms.MenuItem();
			this.menuItem2 = new System.Windows.Forms.MenuItem();
			this.ApplicationIntroduction = new System.Windows.Forms.MenuItem();
			// 
			// mainMenu
			// 
			this.mainMenu.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					 this.File,
																					 this.menuItem2});
			// 
			// File
			// 
			this.File.Index = 0;
			this.File.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																				 this.FileOpen,
																				 this.menuItem1,
																				 this.FileExit});
			this.File.Text = "File";
			// 
			// FileOpen
			// 
			this.FileOpen.Index = 0;
			this.FileOpen.Text = "Open...";
			this.FileOpen.Click += new System.EventHandler(this.FileOpen_Click);
			// 
			// menuItem1
			// 
			this.menuItem1.Index = 1;
			this.menuItem1.Text = "-";
			// 
			// FileExit
			// 
			this.FileExit.Index = 2;
			this.FileExit.Text = "Exit";
			this.FileExit.Click += new System.EventHandler(this.FileExit_Click);
			// 
			// menuItem2
			// 
			this.menuItem2.Index = 1;
			this.menuItem2.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					  this.ApplicationIntroduction});
			this.menuItem2.Text = "Help";
			// 
			// ApplicationIntroduction
			// 
			this.ApplicationIntroduction.Index = 0;
			this.ApplicationIntroduction.Text = "Application Introduction...";
			this.ApplicationIntroduction.Click += new System.EventHandler(this.ApplicationIntroduction_Click);
			// 
			// MainForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(744, 526);
			this.Menu = this.mainMenu;
			this.Name = "MainForm";
			this.Text = "OeVProjectSample";
			this.MouseDown += new System.Windows.Forms.MouseEventHandler(this.MainForm_MouseDown);
			this.Load += new System.EventHandler(this.MainForm_Load);
			this.MouseUp += new System.Windows.Forms.MouseEventHandler(this.MainForm_MouseUp);
			this.Paint += new System.Windows.Forms.PaintEventHandler(this.MainForm_Paint);
			this.MouseMove += new System.Windows.Forms.MouseEventHandler(this.MainForm_MouseMove);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new MainForm());
		}

		private void MainForm_Load(object sender, System.EventArgs e)
		{ 			
			try
            {
                // Set the current ROI handle to 'NoHandle'
                _handle = EDragHandle.NoHandle;
            }
            catch (EException exc)
            {
                MessageBox.Show(exc.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
		}

	    private void ApplicationIntroduction_Click(object sender, System.EventArgs e)
	    {
		    MessageBox.Show(
			        @"Load an image, then use your mouse to drag and resize the ROI.

Suggested image: any gray level image.
Required license: Any",
			    "OeVProjectSample",
			    MessageBoxButtons.OK, MessageBoxIcon.Information);
	    }
        
		private void FileOpen_Click(object sender, System.EventArgs e)
		{
			// Show open file dialog
			openFileDialog.Filter= "Image Files (*.tif;*.jpg;*.bmp;*.png)|*.tif;*.jpg;*.bmp;*.png";
			if(openFileDialog.ShowDialog() == DialogResult.Cancel)
			{
				// No image selected, exit
				return;
			}

            try
            {      
                // Load the selected image
                string strtemp= openFileDialog.FileName;
                _image.Load(strtemp);

                // Attach the ROI to the image
                _roi.Attach(_image);

                // Set the ROI position and size
                _roi.SetPlacement(_image.Width/4, _image.Height/4, _image.Width/2, _image.Height/2);


                //---------------------------------------
                //
                // Insert the image processing code here.
                //
                //---------------------------------------

            }
            catch(EException exc)
            {
                MessageBox.Show(exc.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

			// Refresh the form
			Refresh();
		}

        private void Redraw(Graphics g)
		{
            try
            {
                if (_image.IsVoid)
                {
                    // If image is empty, exit
                    return;
                }

                // Draw the image
                _image.Draw(g);

                // Draw the ROI frame
                _roi.DrawFrame(g, true);


            }
            catch (EException exc)
            {
                if (exc.Error != EError.LicenseMissing)
                {
                    MessageBox.Show(exc.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
		}

		private void MainForm_MouseDown(object sender, System.Windows.Forms.MouseEventArgs e)
		{
			// If the left mouse button is down
			if(e.Button == MouseButtons.Left)
			{
                try
                {
                    if (!_roi.IsVoid)
                    {
                        // Get the ROI handle under the cursor
                        _handle = _roi.HitTest(e.X, e.Y);
                    }
                }
                catch (EException exc)
                {
                    MessageBox.Show(exc.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
			}
		}

		private void MainForm_MouseMove(object sender, System.Windows.Forms.MouseEventArgs e)
		{
            try
            {
                // If there is a handle under the cursor
                if (_handle != EDragHandle.NoHandle)
                {
                    if (!_roi.IsVoid)
                    {
                        // Drag the ROI handle to the cursor position
                        _roi.Drag(_handle, e.X, e.Y);

                        // Redraw the form content
                        Redraw(CreateGraphics());
                        // If there is a handle under the cursor
                    }
                }  
            }
            catch (EException exc)
            {
                if (exc.Error != EError.LicenseMissing)
                {
                    MessageBox.Show(exc.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

		private void MainForm_MouseUp(object sender, System.Windows.Forms.MouseEventArgs e)
		{
           
		    // Reset the current handle to 'NoHandle'
			_handle= EDragHandle.NoHandle;
           
		}

		private void MainForm_Paint(object sender, System.Windows.Forms.PaintEventArgs e)
		{
			// Redraw the form content
			Redraw(e.Graphics);
		}


		private void FileExit_Click(object sender, System.EventArgs e)
		{
			// Close the form
			Close();
		}
    }
}
